package org.javabuilders.swing.swingx;

import javax.swing.JRootPane;
import javax.swing.JToolBar;

import org.javabuilders.BuilderConfig;
import org.javabuilders.layout.DefaultResize;
import org.javabuilders.swing.SwingBuilder;
import org.jdesktop.swingx.JXBusyLabel;
import org.jdesktop.swingx.JXButton;
import org.jdesktop.swingx.JXCollapsiblePane;
import org.jdesktop.swingx.JXColorSelectionButton;
import org.jdesktop.swingx.JXDatePicker;
import org.jdesktop.swingx.JXDialog;
import org.jdesktop.swingx.JXEditorPane;
import org.jdesktop.swingx.JXErrorPane;
import org.jdesktop.swingx.JXFindBar;
import org.jdesktop.swingx.JXFindPanel;
import org.jdesktop.swingx.JXFrame;
import org.jdesktop.swingx.JXGlassBox;
import org.jdesktop.swingx.JXGradientChooser;
import org.jdesktop.swingx.JXGraph;
import org.jdesktop.swingx.JXHeader;
import org.jdesktop.swingx.JXHyperlink;
import org.jdesktop.swingx.JXImagePanel;
import org.jdesktop.swingx.JXImageView;
import org.jdesktop.swingx.JXLabel;
import org.jdesktop.swingx.JXList;
import org.jdesktop.swingx.JXLoginDialog;
import org.jdesktop.swingx.JXLoginPane;
import org.jdesktop.swingx.JXMonthView;
import org.jdesktop.swingx.JXMultiSplitPane;
import org.jdesktop.swingx.JXPanel;
import org.jdesktop.swingx.JXRadioGroup;
import org.jdesktop.swingx.JXRootPane;
import org.jdesktop.swingx.JXSearchPanel;
import org.jdesktop.swingx.JXStatusBar;
import org.jdesktop.swingx.JXTable;
import org.jdesktop.swingx.JXTableHeader;
import org.jdesktop.swingx.JXTaskPane;
import org.jdesktop.swingx.JXTaskPaneContainer;
import org.jdesktop.swingx.JXTipOfTheDay;
import org.jdesktop.swingx.JXTitledPanel;
import org.jdesktop.swingx.JXTitledSeparator;
import org.jdesktop.swingx.JXTree;
import org.jdesktop.swingx.JXTreeTable;
import org.jdesktop.swingx.JXLoginPane.JXLoginFrame;

/**
 * Registers the SwingX components into the specified Java Builder (by default the Java Swing Builder of course)
 * 
 * @author Jacek Furmankiewicx
 */
public final class SwingXConfig
{
    
    /**
     * Constructor.
     * 
     */
    private SwingXConfig()
    {
        // Helper Class
    }
    
    /**
     * Registers SwingX components into the default SwingBuilder.
     */
    public static void register()
    {
        register(SwingBuilder.getConfig());
    }
    
    /**
     * Registers SwingX components into the specified BuilderConfig.
     * 
     * @param config
     *            Builder configuration
     */
    public static void register(BuilderConfig config)
    {
        
        // visual components
        config.addType(JXBusyLabel.class,
                       JXButton.class,
                       JXCollapsiblePane.class,
                       JXColorSelectionButton.class,
                       JXDatePicker.class,
                       JXDialog.class,
                       JXEditorPane.class,
                       JXErrorPane.class,
                       JXFindBar.class,
                       JXFindPanel.class,
                       JXFrame.class,
                       JXGlassBox.class,
                       JXGradientChooser.class,
                       JXGraph.class,
                       JXHeader.class,
                       JXHyperlink.class,
                       JXImagePanel.class,
                       JXImageView.class,
                       JXLabel.class,
                       JXList.class,
                       JXLoginDialog.class,
                       JXLoginFrame.class,
                       JXLoginPane.class,
                       JXMonthView.class,
                       JXMultiSplitPane.class,
                       JXPanel.class,
                       JXRadioGroup.class,
                       JXRootPane.class,
                       JXSearchPanel.class,
                       JXStatusBar.class,
                       JXTable.class,
                       JXTableHeader.class,
                       JXTaskPane.class,
                       JXTaskPaneContainer.class,
                       JXTipOfTheDay.class,
                       JXTitledPanel.class,
                       JXTitledSeparator.class,
                       JXTree.class,
                       JXTreeTable.class);
        
        // JXFrame
        config.forType(JXFrame.class).typeAsMethod(JXStatusBar.class, "setStatusBar").typeAsMethod(JRootPane.class, "setRootPane")
                .typeAsMethod(JToolBar.class, "setToolBar");
        
        config.forType(JXHeader.class).defaultResize(DefaultResize.X_AXIS);
    }
    
}
